@@ -5,14 +5,15 @@ import pytest
 from mythx_models.exceptions import ValidationError
 from mythx_models.request import DetectedIssuesRequest
 
-from . import common as testdata
+from .common import get_test_case
+
+JSON_DATA, DICT_DATA = get_test_case("testdata/detected-issues-request.json")
+OBJ_DATA = DetectedIssuesRequest.from_json(JSON_DATA)
 
 
 def test_analysis_issues_request_from_valid_json():
-    req = DetectedIssuesRequest.from_json(
-        json.dumps(testdata.DETECTED_ISSUES_REQUEST_DICT)
-    )
-    assert req.uuid == testdata.UUID_1
+    req = DetectedIssuesRequest.from_json(json.dumps(DICT_DATA))
+    assert req.uuid == OBJ_DATA.uuid
     assert req.method == "GET"
     assert req.headers == {}
     assert req.parameters == {}
@@ -25,8 +26,8 @@ def test_analysis_issues_request_from_invalid_json():
 
 
 def test_analysis_issues_request_from_valid_dict():
-    req = DetectedIssuesRequest.from_dict(testdata.DETECTED_ISSUES_REQUEST_DICT)
-    assert req.uuid == testdata.UUID_1
+    req = DetectedIssuesRequest.from_dict(DICT_DATA)
+    assert req.uuid == OBJ_DATA.uuid
 
 
 def test_analysis_issues_request_from_invalid_dict():
@@ -35,14 +36,8 @@ def test_analysis_issues_request_from_invalid_dict():
 
 
 def test_analysis_issues_request_to_json():
-    assert (
-        json.loads(testdata.DETECTED_ISSUES_REQUEST_OBJECT.to_json())
-        == testdata.DETECTED_ISSUES_REQUEST_DICT
-    )
+    assert json.loads(OBJ_DATA.to_json()) == DICT_DATA
 
 
 def test_analysis_issues_request_to_dict():
-    assert (
-        testdata.DETECTED_ISSUES_REQUEST_OBJECT.to_dict()
-        == testdata.DETECTED_ISSUES_REQUEST_DICT
-    )
+    assert OBJ_DATA.to_dict() == DICT_DATA
